@@ -2,6 +2,7 @@ package Gscan2pdf::Dialog::Scan;
 
 use warnings;
 use strict;
+no if $] >= 5.018, warnings => "experimental::smartmatch";
 use Glib qw(TRUE FALSE);   # To get TRUE and FALSE
 use Sane 0.05;             # To get SANE_NAME_PAGE_WIDTH & SANE_NAME_PAGE_HEIGHT
 use Gscan2pdf::Dialog;
@@ -214,7 +215,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
  ),
   ];
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.2.5';
 
 my ( $d, $d_sane, $logger, $tooltips );
 my $tolerance = 1;
@@ -607,8 +608,9 @@ sub SET_PROPERTY {
     $self->signal_emit( 'changed-side-to-scan', $newval )
    }
    when ('paper') {
-    set_combobox_by_text( $self->{combobp}, $newval );
-    $self->signal_emit( 'changed-paper', $newval )
+    if ( set_combobox_by_text( $self->{combobp}, $newval ) ) {
+     $self->signal_emit( 'changed-paper', $newval );
+    }
    }
    when ('paper_formats') {
     $self->set_paper_formats($newval);
@@ -660,7 +662,9 @@ sub show {
  my $self = shift;
  $self->signal_chain_from_overridden;
  $self->{framex}->hide_all;
- if ( $self->{combobp}->get_active_text ne $d->get('Manual') ) {
+ if ( defined( $self->{combobp}->get_active_text )
+  and $self->{combobp}->get_active_text ne $d->get('Manual') )
+ {
   $self->hide_geometry( $self->get('available-scan-options') );
  }
  return;
@@ -973,8 +977,11 @@ sub add_profile {
    }
   }
   elsif ( ref($profile) eq 'HASH' ) {
-   while ( my ( $key, $value ) = each( %{$profile} ) ) {
-    push @{ $self->{profiles}{$name} }, { $key => $value };
+
+   # If the profile is a hash, the order is undefined.
+   # Sort it to be consistent for tests.
+   for my $key ( sort keys %{$profile} ) {
+    push @{ $self->{profiles}{$name} }, { $key => $profile->{$key} };
    }
   }
   $self->{combobsp}->append_text($name);
@@ -1065,7 +1072,11 @@ sub get_combobox_by_text {
 sub set_combobox_by_text {
  my ( $combobox, $text ) = @_;
  if ( defined $combobox ) {
-  $combobox->set_active( get_combobox_by_text( $combobox, $text ) );
+  my $index = get_combobox_by_text( $combobox, $text );
+  if ( $index > $_NO_INDEX or not defined($text) ) {
+   $combobox->set_active($index);
+   return TRUE;
+  }
  }
  return;
 }
