@@ -2,6 +2,7 @@ package Gscan2pdf::Dialog::Scan::Sane;
 
 use warnings;
 use strict;
+no if $] >= 5.018, warnings => "experimental::smartmatch";
 use Gscan2pdf::Dialog::Scan;
 use Glib qw(TRUE FALSE);   # To get TRUE and FALSE
 use Sane 0.05;             # To get SANE_NAME_PAGE_WIDTH & SANE_NAME_PAGE_HEIGHT
@@ -20,7 +21,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
  ),
 ];
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.2.5';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -432,6 +433,7 @@ sub hide_geometry {
 
 sub set_option {
  my ( $self, $option, $val ) = @_;
+ if ( not defined($option) ) { return }
 
  my $current = $self->{current_scan_options};
 
@@ -459,6 +461,10 @@ sub set_option {
    if ($data) {
     $self->update_options( Gscan2pdf::Scanner::Options->new_from_data($data) );
    }
+   else {
+    my $opt = $options->by_name( $option->{name} );
+    $opt->{val} = $val;
+   }
 
    # We can carry on applying defaults now, if necessary.
    $self->signal_emit( 'finished-process', 'set_option' );
@@ -687,7 +693,7 @@ sub set_option_widget {
    # check for it here, so that the reloaded value is not overwritten.
    $opt->{val} = $val;
   }
-  else {
+  elsif ( defined $widget ) {
    given ($widget) {
     when ( $widget->isa('Gtk2::CheckButton') ) {
      if ( $widget->get_active != $val ) {
@@ -719,6 +725,9 @@ sub set_option_widget {
     }
    }
   }
+  else {
+   $logger->warn("Widget for option '$name' undefined.");
+  }
   ++$i;
  }
 
