@@ -3,6 +3,7 @@ package Gscan2pdf::Document;
 use strict;
 use warnings;
 use feature "switch";
+no if $] >= 5.018, warnings => "experimental::smartmatch";
 
 use threads;
 use threads::shared;
@@ -39,7 +40,7 @@ BEGIN {
  use Exporter ();
  our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
- $VERSION = '1.2.3';
+ $VERSION = '1.2.5';
 
  use base qw(Exporter Gtk2::Ex::Simple::List);
  %EXPORT_TAGS = ();                      # eg: TAG => [ qw!name1 name2! ],
@@ -165,6 +166,8 @@ sub import_file {
 
  # File in which to store the process ID so that it can be killed if necessary
  my $pidfile = File::Temp->new( DIR => $self->{dir}, SUFFIX => '.pid' );
+ my $dirname = '';
+ if ( defined $self->{dir} ) { $dirname = "$self->{dir}" }
 
  my $sentinel = _enqueue_request(
   'import-file',
@@ -172,7 +175,7 @@ sub import_file {
    info    => $options{info},
    first   => $options{first},
    last    => $options{last},
-   dir     => "$self->{dir}",
+   dir     => $dirname,
    pidfile => "$pidfile"
   }
  );
@@ -225,30 +228,42 @@ sub fetch_file {
 
 sub pages_possible {
  my ( $self, $start, $step ) = @_;
- my $n = 0;
  my $i = $#{ $self->{data} };
+
+ # Empty document and negative step
+ if ( $i < 0 and $step < 0 ) {
+  return -$start / $step;
+ }
+
+ # Empty document, or start page after end of document, allow infinite pages
+ elsif ( ( $i < 0 or $self->{data}[$i][0] < $start )
+  and $step > 0 )
+ {
+  return -1;    ## no critic (ProhibitMagicNumbers)
+ }
+
+ # track backwards to find index before which start page would be inserted
+ while ( $i > 0 and $self->{data}[ $i - 1 ][0] > $start ) {
+  --$i;
+ }
+
+ # scan in appropriate direction, looking for position for last page
+ my $n = 0;
  while (TRUE) {
 
-  # Settings take us into negative page range
-  if ( $start + $n * $step < 1 ) {    ## no critic (ProhibitCascadingIfElse)
+  # fallen off bottom of index
+  if ( $i < 0 ) {    ## no critic (ProhibitCascadingIfElse)
    return $n;
   }
 
-  # Empty document and negative step
-  elsif ( $i < 0 and $step < 0 ) {
-   return -$start / $step;
+  # fallen off top of index
+  elsif ( $i > $#{ $self->{data} } ) {
+   return -1         ## no critic (ProhibitMagicNumbers)
   }
 
-  # Empty document, or checked beyond end of document, allow infinite pages
-  elsif (
-   (
-    @{ $self->{data} } == 0
-    or $self->{data}[ $#{ $self->{data} } ][0] < $start
-   )
-   and $step > 0
-    )
-  {
-   return -1;    ## no critic (ProhibitMagicNumbers)
+  # Settings take us into negative page range
+  elsif ( $start + $n * $step < 1 ) {
+   return $n;
   }
 
   # Found existing page
@@ -256,14 +271,21 @@ sub pages_possible {
    return $n;
   }
 
-  # Current page doesn't exist, check for at least one more
-  elsif ( $n == 0 ) {
+  # increment index
+  elsif ( $step > 1 and $self->{data}[$i][0] < $start + $n * $step ) {
+   ++$i;
    ++$n;
   }
 
-  # In the middle of the document, scan back to find page nearer start
-  elsif ( $self->{data}[$i][0] > $start + $n * $step and $i > 0 ) {
+  # decrement index
+  elsif ( $step < 0 and $self->{data}[$i][0] > $start + $n * $step ) {
    --$i;
+   ++$n;
+  }
+
+  # Current page doesn't exist, check for at least one more
+  elsif ( $n == 0 ) {
+   ++$n;
   }
 
   # Try one more page
@@ -1117,7 +1139,7 @@ sub get_page_index {
  my ( $self, $page_range, $error_callback ) = @_;
  my @index;
  if ( $page_range eq 'all' ) {
-  if ( $#{ $self->{data} } > -1 ) {
+  if ( @{ $self->{data} } ) {
    return 0 .. $#{ $self->{data} };
   }
   else {
@@ -1905,7 +1927,7 @@ sub _convert_image_for_pdf {
    my $h_pixels = $pagedata->{h} * $output_resolution;
 
    $logger->info("Resizing $filename to $w_pixels x $h_pixels");
-   my $status = $image->Resize( width => $w_pixels, height => $h_pixels );
+   my $status = $image->Sample( width => $w_pixels, height => $h_pixels );
    if ("$status") { $logger->warn($status) }
   }
   if ( defined( $options{options}->{quality} ) and $compression eq 'jpg' ) {
@@ -1945,16 +1967,8 @@ sub _write_image_object {
   or ( $compression =~ /(?:jpg|png)/xsm )
   or $downsample )
  {
-
-  # depth required because resize otherwise increases depth
-  # to maintain information
-  if ( not defined( $pagedata->{depth} ) ) {
-   $pagedata->{depth} = $image->Get('depth');
-  }
-  $logger->info(
-   "Writing temporary image $filename with depth $pagedata->{depth}");
-  my $status =
-    $image->Write( filename => $filename, depth => $pagedata->{depth} );
+  $logger->info("Writing temporary image $filename");
+  my $status = $image->Write( filename => $filename );
   return if $_self->{cancel};
   if ("$status") { $logger->warn($status) }
   if ( $filename =~ /\.(\w*)$/xsm ) {
@@ -2307,9 +2321,12 @@ sub _thread_rotate {
 sub _thread_save_image {
  my ( $self, $path, $list_of_pages, $pidfile ) = @_;
 
+ # Escape quotes and spaces
+ $path =~ s/(['" ])/\\$1/gxsm;
+
  if ( @{$list_of_pages} == 1 ) {
   my $cmd =
-"convert $list_of_pages->[0]{filename} -density $list_of_pages->[0]{resolution} '$path'";
+"convert $list_of_pages->[0]{filename} -density $list_of_pages->[0]{resolution} $path";
   $logger->info($cmd);
   my $status = system("echo $PROCESS_ID > $pidfile;$cmd");
   return if $_self->{cancel};
@@ -2323,7 +2340,7 @@ sub _thread_save_image {
   my $i = 1;
   foreach ( @{$list_of_pages} ) {
    $current_filename = sprintf $path, $i++;
-   my $cmd = sprintf "convert %s -density %d \"%s\"",
+   my $cmd = sprintf "convert %s -density %d %s",
      $_->{filename}, $_->{resolution},
      $current_filename;
    my $status = system("echo $PROCESS_ID > $pidfile;$cmd");
@@ -2684,6 +2701,12 @@ sub _thread_unpaper {
   delete   => TRUE,
   format   => 'Portable anymap',
  );
+
+ # unpaper doesn't change the resolution, so we can safely copy it
+ if ( defined $page->{resolution} ) {
+  $new->{resolution} = $page->{resolution};
+ }
+
  $new->{dirty_time} = timestamp();    #flag as dirty
  my %data = ( old => $page, new => $new->freeze );
  if ( $out2 ne $EMPTY ) {
@@ -2693,6 +2716,12 @@ sub _thread_unpaper {
    delete   => TRUE,
    format   => 'Portable anymap',
   );
+
+  # unpaper doesn't change the resolution, so we can safely copy it
+  if ( defined $page->{resolution} ) {
+   $new2->{resolution} = $page->{resolution};
+  }
+
   $new2->{dirty_time} = timestamp();    #flag as dirty
   $data{new2} = $new2->freeze;
  }
