@@ -24,7 +24,7 @@ BEGIN {
  use Exporter ();
  our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
- $VERSION = '1.2.3';
+ $VERSION = '1.2.5';
 
  use base qw(Exporter);
  %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -179,7 +179,7 @@ sub boxes {
   }
  }
  else {
-  push @boxes, [ 0, 0, $self->{w}, $self->{h}, decode_utf8( $self->{hocr} ) ];
+  push @boxes, [ 0, 0, $self->{w}, $self->{h}, $self->{hocr} ];
  }
  return @boxes;
 }
@@ -222,9 +222,20 @@ sub resolution {
   }
 
   if ( $self->{resolution} ) {
-   if ( not $image->Get('units') eq 'PixelsPerInch' ) {
+   my $units = $image->Get('units');
+   if ( $units eq 'pixels / centimeter' ) {
     $self->{resolution} *= $CM_PER_INCH;
    }
+   elsif ( $units =~ /undefined/xsm ) {
+    $logger->warn("Undefined units.");
+   }
+   elsif ( $units ne 'pixels / inch' ) {
+    $logger->warn("Unknown units: '$units'.");
+    $units = 'undefined';
+   }
+   if ( $units =~ /undefined/xsm ) {
+    $logger->warn('The resolution and page size will probably be wrong.');
+   }
    return $self->{resolution};
   }
  }
