@@ -2,6 +2,7 @@ package Gscan2pdf::Scanner::Options;
 
 use strict;
 use warnings;
+no if $] >= 5.018, warnings => "experimental::smartmatch";
 use Carp;
 use Glib qw(TRUE FALSE);    # To get TRUE and FALSE
 use Sane 0.05;              # For enums
@@ -11,7 +12,7 @@ Readonly my $MAX_VALUES => 255;
 
 use Glib::Object::Subclass Glib::Object::;
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.2.5';
 
 my $units = qr{(pel|bit|mm|dpi|%|us)}xsm;
 my $EMPTY = q{};
@@ -52,7 +53,9 @@ sub by_index {
 
 sub by_name {
  my ( $self, $name ) = @_;
- return defined($name) ? $self->{hash}{$name} : undef;
+ return ( defined($name) and defined( $self->{hash}{$name} ) )
+   ? $self->{hash}{$name}
+   : undef;
 }
 
 sub by_title {
