@@ -10,7 +10,7 @@ use Gscan2pdf::Document;             # for slurp
 use version;
 use English qw( -no_match_vars );    # for $PROCESS_ID
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.2.5';
 my $EMPTY = q{};
 my $COMMA = q{,};
 
@@ -185,8 +185,16 @@ sub hocr {
  if ( not $setup ) { Gscan2pdf::Tesseract->setup($logger) }
 
  # Temporary filename for output
- my $suffix =
-   version->parse("v$version") >= version->parse("v3") ? '.html' : '.txt';
+ my $suffix;
+ if ( version->parse("v$version") >= version->parse("v3.02") ) {
+  $suffix = '.hocr';
+ }
+ elsif ( version->parse("v$version") >= version->parse("v3") ) {
+  $suffix = '.html';
+ }
+ else {
+  $suffix = '.txt';
+ }
  my $txt = File::Temp->new( SUFFIX => $suffix );
  ( $name, $path, undef ) = fileparse( $txt, $suffix );
 
