@@ -4,6 +4,7 @@ use 5.008005;
 use strict;
 use warnings;
 use feature "switch";
+no if $] >= 5.018, warnings => "experimental::smartmatch";
 use Carp;
 use Glib qw(TRUE FALSE);     # To get TRUE and FALSE
 use Gtk2;
@@ -17,7 +18,7 @@ BEGIN {
  use Exporter ();
  our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
- $VERSION = '1.2.3';
+ $VERSION = '1.2.5';
 
  use base qw(Exporter);
  %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -390,7 +391,7 @@ sub add_widget {
    foreach ( keys %{ $hashref->{$option}{options} } ) {
     $widget->append_text( $hashref->{$option}{options}{$_}{string} );
     push @tooltip, $hashref->{$option}{options}{$_}{tooltip};
-    if ( $_ eq $default->{$option} ) { $o = $i }
+    if (/^$default->{$option}$/ixsm) { $o = $i }
     $hashref->{$option}{options}{$_}{index} = $i++;
    }
    $widget->signal_connect(
@@ -504,7 +505,7 @@ sub get_options {
     }
     when ('CheckButtonGroup') {
      my @items;
-     foreach ( keys %{ $hashref->{$option}{options} } ) {
+     foreach ( sort keys %{ $hashref->{$option}{options} } ) {
       if ( $hashref->{$option}{options}{$_}{widget}->get_active ) {
        push @items, $_;
       }
@@ -532,7 +533,7 @@ sub get_cmdline {
  my $default = $self->get_options;
 
  my @items;
- foreach my $option ( keys %{$hashref} ) {
+ foreach my $option ( sort keys %{$hashref} ) {
   if ( $hashref->{$option}{type} eq 'CheckButton' ) {
    if ( defined $default->{$option} and $default->{$option} ) {
     push @items, "--$option";
